#
#  Name:    MpNum.py
#
#  Purpose: Python module interface to MX using NumPy arrays.
#
#  Author:  William Lavender
#
#-----------------------------------------------------------------------
#
#  Copyright 2006, 2009 Illinois Institute of Technology
#
#  See the file "LICENSE" for information on usage and redistribution
#  of this file, and for a DISCLAIMER OF ALL WARRANTIES.
#

#
# Import NumPy if it has not yet been imported by another package
# such as matplotlib.
#

import sys
import numpy
import Mp
import MpPrivate

#----------------------------------------------------------------------------

def _get_numpy_type_from_mx_type( mx_datatype ):
	if ( mx_datatype == 1 ):
		return "str_"

	elif ( mx_datatype == 2 ):
		return "int8"

	elif ( mx_datatype == 3 ):
		return "uint8"

	elif ( mx_datatype == 4 ):
		return "int16"

	elif ( mx_datatype == 5 ):
		return "uint16"

	elif ( mx_datatype == 6 ):
		return "int32"

	# MX datatype 7 is reserved.

	# FIXME: We need to check for 64-bit machines here.

	elif ( mx_datatype == 8 ):
		return "int32"

	elif ( mx_datatype == 9 ):
		return "uint32"

	elif ( mx_datatype == 10 ):
		return "float32"

	elif ( mx_datatype == 11 ):
		return "float64"

	elif ( mx_datatype == 12 ):
		return "uint32"      # WARNING: This must match type 9!

	# MX datatype 13 is reserved.

	elif ( mx_datatype == 14 ):
		return "int64"

	elif ( mx_datatype == 15 ):
		return "uint64"

	else:
		msg = "Unsupported MX type %d requested." % mx_datatype
		raise TypeError, msg

#----------------------------------------------------------------------------

#
#  Net class - Used to access individual network fields in a remote server
#              using NumPy arrays.
#

class Net(Mp.Net):

	def get( self ):
		if ( hasattr( self, "datatype" ) == 0 ):
			self.get_field_parameters()

			self.numpy_type = \
				_get_numpy_type_from_mx_type( self.datatype )

		binary_string = \
			MpPrivate.net_get_remote_binary_string( self.handle )

		array = numpy.fromstring( binary_string, dtype=self.numpy_type )

		shaped_array = numpy.reshape( array, self.dimension_tuple )

		return shaped_array

#- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 

	def put( self, args ):
		if ( hasattr( self, "datatype" ) == 0 ):
			self.get_field_parameters()

			self.numpy_type = \
				_get_numpy_type_from_mx_type( self.datatype )

		try:
			# Will succeed if 'args' is a NumPy array.
			#
			# FIXME: Not yet really tested.

			binary_string = args.tostring()
		except:
			# We get here if 'args' is not a NumPy array.

			binary_string = Mp._convert_sequence_to_binary_string( \
					args,                       \
					self.datatype,              \
					self.num_dimensions,        \
					self.dimension_tuple,       \
					self.data_element_size_tuple[0], \
					self.name )

		MpPrivate.net_put_remote_binary_string( self.handle, \
							binary_string )

