/*
 * Name:    mp.h
 *
 * Purpose: Python module interface to the MX library.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002-2009 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#ifndef __MP_H__
#define __MP_H__

#include "mx_image.h"

#define MXP_MAX_DIMENSIONS	100

/* The following definitions are used by MpPrivate_create_sequence_from_field().
 */

#define MXP_ST_TUPLE		1
#define MXP_ST_LIST		2

#if 0
typedef struct {
	long datatype;
	long num_dimensions;
	long *dimension_array;
	size_t *data_element_size_array;
	size_t array_size;

	void *value_array;

	void *buffer_ptr;
} MPPRIVATE_NETWORK_FIELD;
#endif

/*------- libMp functions -------*/

MX_API      void MpError_SetString( PyObject *exception_object,
					char *format, ... );

MX_API PyObject *MpError_SetFromMxStatus( PyObject *error_object,
					mx_status_type mx_status );

MX_API PyObject *MpError_Init( PyObject *module_object );

/*------- MpPrivate functions -------*/

/* Module initialization function. */

MX_API void initMpPrivate( void );

/* Global variables. */

extern MX_HANDLE_TABLE *MpPrivate_global_record_handle_table;

extern MX_HANDLE_TABLE *MpPrivate_global_network_field_handle_table;

extern MX_HANDLE_TABLE *MpPrivate_global_image_frame_handle_table;

/* Module functions. */

MX_API mx_status_type MpPrivate_get_record_from_handle( long handle,
							MX_RECORD **record );

MX_API mx_status_type MpPrivate_get_record_from_object( PyObject *object,
							MX_RECORD **record );

MX_API           void MpPrivate_print_object( PyObject *object );

MX_API mx_status_type MpPrivate_create_field_from_tuple( MX_RECORD *record,
							MX_RECORD_FIELD *field,
							PyObject *tuple );

MX_API mx_status_type MpPrivate_create_tuple_from_field( MX_RECORD *record,
							MX_RECORD_FIELD *field,
							PyObject **new_tuple );

MX_API PyObject *MpPrivate_init_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_init_exceptions_cmd( PyObject *self, PyObject *args);

/*===*/

MX_API PyObject *MpPrivate_info_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_info_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scanlog_info_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_scanlog_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_scanlog_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_warning_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_warning_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_error_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_debug_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_debug_output_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_debug_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_debug_level_cmd( PyObject *self,
							PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_info_dialog_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_info_dialog_function_cmd( PyObject *self,
							PyObject *args );
/*===*/

MX_API PyObject *MpPrivate_info_entry_dialog_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_info_entry_dialog_function_cmd( PyObject *self,
							PyObject *args );
/*===*/

MX_API PyObject *MpPrivate_user_requested_interrupt_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_user_requested_interrupt_or_pause_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_user_interrupt_function_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_scan_pause_request_handler_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_getch_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_kbhit_cmd( PyObject *self, PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_plotting_is_enabled_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_plot_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_program_name_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_install_user_interrupt_handler_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_install_output_handlers_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_install_dialog_handler_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_change_filename_prefix_cmd( PyObject *self,
							PyObject *args );

/*===*/

MX_API PyObject *MpPrivate_create_record_list_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_read_database_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_finish_database_initialization_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_initialize_hardware_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_shutdown_hardware_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_resynchronize_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_create_record_from_description_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_finish_record_initialization_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_open_hardware_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_close_hardware_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_delete_record_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_record_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_next_record_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_record_name_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_create_description_from_record_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_get_field_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_set_field_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_get_object_class_name_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_get_version_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_start_c_debugger_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_c_breakpoint_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_c_set_debugger_started_flag_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_parse_network_field_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_connect_to_mx_server_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_wait_for_messages_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_set_network_debug_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_net_init_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_net_del_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_net_get_field_parameters_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_get_remote_binary_string_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_put_remote_binary_string_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_get_local_binary_string_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_get_object_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_net_put_object_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_net_get_attribute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_set_attribute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_get_attribute_number_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_add_callback_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_net_del_callback_cmd( PyObject *self,
							PyObject *args );


MX_API mx_status_type MpPrivate_get_image_frame_from_handle( long handle,
						MX_IMAGE_FRAME **frame );

MX_API PyObject *MpPrivate_image_init_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_image_del_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_image_get_format_type_from_name_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_image_get_format_name_from_type_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_image_get_exposure_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_image_get_image_data_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_image_read_file_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_image_write_file_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_camac_command_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_camac_get_lam_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_camac_controller_command_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_gpib_getline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_putline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_interface_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_device_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_selective_device_clear_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_local_lockout_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_remote_enable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_go_to_local_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_trigger_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_gpib_wait_for_service_request_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_serial_poll_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_gpib_serial_poll_disable_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_modbus_read_coils_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_discrete_inputs_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_holding_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_input_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_single_coil_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_single_register_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_exception_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_get_comm_event_counter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_multiple_coils_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_write_multiple_registers_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_mask_write_register_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_write_multiple_registers_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_modbus_read_fifo_queue_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_portio_inp8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_inp16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_outp8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_portio_outp16_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_rs232_getchar_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_putchar_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_write_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_getline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_putline_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_rs232_num_input_bytes_available_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_discard_unread_input_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_discard_unwritten_output_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_get_signal_state_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_rs232_set_signal_state_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_usb_enumerate_devices_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_find_device_by_order_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_find_device_by_serial_number_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_delete_device_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_reset_device_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_control_transfer_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_usb_bulk_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_usb_bulk_write_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_vme_in8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_in16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_in32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_out32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in16_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_in32_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out8_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out16_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_multi_out32_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_get_read_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_set_read_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_get_write_address_increment_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_vme_set_write_address_increment_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_amplifier_get_gain_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_gain_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_get_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_get_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_amplifier_set_time_constant_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_analog_input_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ainput_read_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ainput_read_raw_double_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_get_dark_current_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_input_set_dark_current_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_analog_output_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_read_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_read_raw_double_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_analog_output_write_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_write_raw_long_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_aoutput_write_raw_double_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_area_detector_get_image_format_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_image_format_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_maximum_framesize_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_framesize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_framesize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_binsize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_binsize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_bytes_per_frame_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_bytes_per_pixel_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_bits_per_pixel_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_correction_flags_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_correction_flags_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_measure_correction_frame_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_use_scaled_dark_current_flag_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_use_scaled_dark_current_flag_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_detector_readout_time_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_total_sequence_time_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_sequence_parameters_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_sequence_parameters_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_trigger_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_set_trigger_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_arm_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_trigger_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_start_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_stop_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_is_busy_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_last_frame_number_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_total_num_frames_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_extended_status_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_setup_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_readout_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_correct_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_transfer_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_load_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_save_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_copy_frame_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_area_detector_get_frame_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_autoscale_read_monitor_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_change_request_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_change_control_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_offset_index_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_set_offset_index_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_offsets_cmd( PyObject *self,
							PyObject *args );
					
MX_API PyObject *MpPrivate_autoscale_set_offsets_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_get_limits_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_set_limits_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_autoscale_compute_dynamic_limits_cmd(
					PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_digital_input_read_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_digital_output_read_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_digital_output_write_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_digital_output_pulse_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_encoder_get_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_encoder_reset_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_encoder_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_encoder_write_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_mca_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_start_without_preset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_with_preset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_live_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_real_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_start_for_preset_count_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_parameter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_parameter_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_preset_type_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_preset_type_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_preset_count_region_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_preset_count_region_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_set_roi_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_integral_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_rois_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_set_rois_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mca_get_roi_integrals_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_num_channels_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_num_channels_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_channel_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_real_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_live_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_soft_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_soft_roi_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_soft_roi_integral_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_soft_roi_integrals_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_energy_scale_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_energy_scale_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_energy_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_set_energy_offset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mca_get_energy_axis_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_mce_get_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mce_reset_overflow_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mce_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mce_get_current_num_values_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_mcs_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_all_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_scaler_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_measurement_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_read_timer_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_measurement_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_measurement_time_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_measurement_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_measurement_counts_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_get_num_measurements_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_mcs_set_num_measurements_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_motor_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_motor_move_absolute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_relative_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_absolute_with_flags_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_move_relative_with_flags_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_wait_for_motor_stop_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_positive_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_negative_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_find_home_position_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_constant_velocity_move_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_extended_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_base_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_base_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_maximum_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_maximum_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_save_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_restore_speed_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_speed_between_positions_cmd(
							PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_type_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_raw_accel_parameters_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_raw_accel_parameters_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_time_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_accel_time_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_accel_distance_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_home_search_succeeded_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_get_gain_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_set_gain_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_motor_send_control_command_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_multiple_motors_move_absolute_with_flags_cmd(
							PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_wait_for_multiple_motors_stop_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_ptz_command_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_status_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_pan_left_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_pan_right_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_pan_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_pan_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_pan_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_pan_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_pan_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_tilt_up_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_tilt_down_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_tilt_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_tilt_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_tilt_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_tilt_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_tilt_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_zoom_in_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_zoom_out_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_zoom_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_zoom_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_zoom_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_zoom_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_zoom_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_zoom_off_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_zoom_on_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_focus_manual_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_focus_auto_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_focus_far_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_focus_near_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_focus_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_focus_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_focus_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_ptz_get_focus_speed_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_ptz_set_focus_speed_cmd( PyObject *self,
							PyObject *args );



MX_API PyObject *MpPrivate_pulse_generator_is_busy_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_start_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_stop_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_period_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_period_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_width_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_width_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_num_pulses_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_num_pulses_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_get_pulse_delay_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_pulse_generator_set_pulse_delay_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_relay_relay_command_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_relay_get_relay_status_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_sample_changer_initialize_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_shutdown_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_select_sample_holder_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_unselect_sample_holder_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_grab_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_ungrab_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_mount_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_unmount_sample_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_get_sample_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_set_sample_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_idle_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_reset_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_get_status_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_is_busy_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_cooldown_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sample_changer_deice_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_sca_get_lower_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_lower_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_upper_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_upper_level_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_gain_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_set_gain_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_get_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_set_time_constant_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_sca_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_sca_set_mode_cmd( PyObject *self, PyObject *args );


MX_API PyObject *MpPrivate_scaler_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_overflow_set_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_read_raw_cmd( PyObject *self, PyObject *args);

MX_API PyObject *MpPrivate_scaler_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_scaler_get_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_mode_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_modes_of_associated_counters_cmd(
							PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_get_dark_current_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_scaler_set_dark_current_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_table_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_table_move_absolute_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_get_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_set_position_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_soft_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_immediate_abort_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_table_positive_limit_hit_cmd( PyObject *self, 
							PyObject *args );

MX_API PyObject *MpPrivate_table_negative_limit_hit_cmd( PyObject *self, 
							PyObject *args );


MX_API PyObject *MpPrivate_timer_is_busy_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_start_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_stop_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_clear_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_read_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_get_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_set_mode_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_set_modes_of_associated_counters_cmd(
					PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_timer_get_last_measurement_time_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_scan_perform_scan_cmd( PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_send_variable_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_receive_variable_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_server_wait_for_message_id_cmd( PyObject *self,
							PyObject *args );

MX_API PyObject *MpPrivate_server_wait_for_messages_from_server_cmd(
							PyObject *self,
							PyObject *args );


MX_API PyObject *MpPrivate_log_open_cmd( PyObject *self, PyObject *args );

MX_API PyObject *MpPrivate_log_close_cmd( PyObject *self, PyObject *args );

/*
 * Exception objects.
 */

MX_API PyObject *MpPrivateExc_Error;

MX_API PyObject *MpPrivateExc_Success;
MX_API PyObject *MpPrivateExc_Null_Argument;
MX_API PyObject *MpPrivateExc_Illegal_Argument;
MX_API PyObject *MpPrivateExc_Corrupt_Data_Structure;
MX_API PyObject *MpPrivateExc_Unparseable_String;
MX_API PyObject *MpPrivateExc_End_Of_Data;
MX_API PyObject *MpPrivateExc_Unexpected_End_Of_Data;
MX_API PyObject *MpPrivateExc_Not_Found;
MX_API PyObject *MpPrivateExc_Type_Mismatch;
MX_API PyObject *MpPrivateExc_Not_Yet_Implemented;
MX_API PyObject *MpPrivateExc_Unsupported;
MX_API PyObject *MpPrivateExc_Out_Of_Memory;
MX_API PyObject *MpPrivateExc_Would_Exceed_Limit;
MX_API PyObject *MpPrivateExc_Limit_Was_Exceeded;
MX_API PyObject *MpPrivateExc_Interface_IO_Error;
MX_API PyObject *MpPrivateExc_Device_IO_Error;
MX_API PyObject *MpPrivateExc_File_IO_Error;
MX_API PyObject *MpPrivateExc_Terminal_IO_Error;
MX_API PyObject *MpPrivateExc_IPC_IO_Error;
MX_API PyObject *MpPrivateExc_IPC_Connection_Lost;
MX_API PyObject *MpPrivateExc_Network_IO_Error;
MX_API PyObject *MpPrivateExc_Network_Connection_Lost;
MX_API PyObject *MpPrivateExc_Not_Ready;
MX_API PyObject *MpPrivateExc_Interrupted;
MX_API PyObject *MpPrivateExc_Pause_Requested;
MX_API PyObject *MpPrivateExc_Interface_Action_Failed;
MX_API PyObject *MpPrivateExc_Device_Action_Failed;
MX_API PyObject *MpPrivateExc_Function_Failed;
MX_API PyObject *MpPrivateExc_Controller_Internal_Error;
MX_API PyObject *MpPrivateExc_Permission_Denied;
MX_API PyObject *MpPrivateExc_Client_Request_Denied;
MX_API PyObject *MpPrivateExc_Try_Again;
MX_API PyObject *MpPrivateExc_Timed_Out;
MX_API PyObject *MpPrivateExc_Hardware_Configuration_Error;
MX_API PyObject *MpPrivateExc_Hardware_Fault;
MX_API PyObject *MpPrivateExc_Record_Disabled_Due_To_Fault;
MX_API PyObject *MpPrivateExc_Record_Disabled_By_User;
MX_API PyObject *MpPrivateExc_Initialization_Error;
MX_API PyObject *MpPrivateExc_Read_Only;
MX_API PyObject *MpPrivateExc_Software_Configuration_Error;
MX_API PyObject *MpPrivateExc_Operating_System_Error;
MX_API PyObject *MpPrivateExc_Unknown_Error;
MX_API PyObject *MpPrivateExc_Not_Valid_For_Current_State;
MX_API PyObject *MpPrivateExc_Configuration_Conflict;
MX_API PyObject *MpPrivateExc_Not_Available;
MX_API PyObject *MpPrivateExc_Stop_Requested;
MX_API PyObject *MpPrivateExc_Bad_Handle;
MX_API PyObject *MpPrivateExc_Object_Abandoned;
MX_API PyObject *MpPrivateExc_Might_Cause_Deadlock;
MX_API PyObject *MpPrivateExc_Already_Exists;
MX_API PyObject *MpPrivateExc_Invalid_Callback;
MX_API PyObject *MpPrivateExc_Early_Exit;

#endif /* __MP_H__ */

