/*
 * Name:    mp_digital_output.c
 *
 * Purpose: Python module interface to generic MX digital output functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002, 2008-2009 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"
#include "mx_record.h"
#include "mx_digital_output.h"
#include "mx_handle.h"
#include "mp.h"

MX_EXPORT PyObject *
MpPrivate_digital_output_read_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	unsigned long value;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_digital_output_read( record, &value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", (long) value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_digital_output_write_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle, value;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_digital_output_write( record, (unsigned long) value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_digital_output_pulse_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	int parse_status, busy_wait;
	long handle, polarity;
	unsigned long pulse_duration_in_microseconds;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "llil", &handle,
					&polarity, &busy_wait,
					&pulse_duration_in_microseconds );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_digital_output_pulse( record,
					polarity, busy_wait,
					pulse_duration_in_microseconds );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

