/*
 * Name:    mp_encoder.c
 *
 * Purpose: Python module interface to generic MX encoder functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2002, 2009 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"
#include "mx_record.h"
#include "mx_encoder.h"
#include "mx_handle.h"
#include "mp.h"

MX_EXPORT PyObject *
MpPrivate_encoder_get_overflow_status_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status, underflow_set, overflow_set;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_encoder_get_overflow_status( record,
					&underflow_set, &overflow_set );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "ii", underflow_set, overflow_set );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_encoder_reset_overflow_status_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_encoder_reset_overflow_status( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_encoder_read_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	int parse_status;
	long handle, value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_encoder_read( record, &value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_encoder_write_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	int parse_status;
	long handle, value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_encoder_write( record, value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

