/*
 * Name:    mp_server.c
 *
 * Purpose: Python module interface to generic MX server functions.
 *
 * Author:  William Lavender
 *
 *---------------------------------------------------------------------------
 *
 * Copyright 2008-2009 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"
#include "mx_record.h"
#include "mx_net.h"
#include "mx_handle.h"
#include "mp.h"

MX_EXPORT PyObject *
MpPrivate_server_wait_for_message_id_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *server_record;
	long server_handle;
	unsigned long message_id;
	double timeout_in_seconds;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "lld",
			&server_handle, &message_id, &timeout_in_seconds );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( server_handle,
							&server_record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_network_wait_for_message_id( server_record, NULL,
					message_id, timeout_in_seconds );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_server_wait_for_messages_from_server_cmd( PyObject *self,
							PyObject *args )
{
	MX_RECORD *server_record;
	long server_handle;
	double timeout_in_seconds;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ld",
				&server_handle, &timeout_in_seconds );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( server_handle,
							&server_record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_network_wait_for_messages_from_server( server_record,
							timeout_in_seconds );

	if ( mx_status.code != MXE_SUCCESS )
		return MpError_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

